#
# spec file for package cura
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# 'qmlimport(Cura.1)' - Internal QML import
# 'qmlimport(DigitalFactory.1) - Internal, registered from plugins/DigitalLibrary/src/DigitalFactoryController.py
%global __requires_exclude qmlimport\\((Cura|DigitalFactory)\\..*

Name:           cura
%define sversion        4.13.1
Version:        4.13.1
Release:        2.7
Summary:        3D printer control software
License:        LGPL-3.0-only
Group:          Hardware/Printing
URL:            https://github.com/Ultimaker/Cura
Source:         https://github.com/Ultimaker/Cura/archive/%{sversion}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE disable-code-style-check.patch code style is no distro business
Patch1:         disable-code-style-check.patch
# PATCH-FIX-UPSTREAM - remove unused import of sentry_sdk
Patch2:         https://github.com/Ultimaker/Cura/commit/aad41807c365ccef001b787407d7dc756e11de02.patch#/remove_unused_sentry_sdk.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  python3-Arcus >= %{version}
BuildRequires:  python3-Savitar >= %{version}
BuildRequires:  python3-keyring >= 21
BuildRequires:  python3-numpy
BuildRequires:  python3-pynest2d
BuildRequires:  python3-pytest
BuildRequires:  python3-qt5
BuildRequires:  python3-requests
BuildRequires:  python3-scipy
BuildRequires:  python3-shapely
BuildRequires:  python3-zeroconf
BuildRequires:  update-desktop-files
BuildRequires:  uranium >= %{version}
# It builds with older Qt, but crashes due to missing qml features
BuildRequires:  pkgconfig(Qt5Core) >= 5.10
Requires:       cura-engine >= %{version}
Requires:       python3-Arcus >= %{version}
Requires:       python3-Savitar >= %{version}
Requires:       python3-keyring >= 21
Requires:       python3-numpy
Requires:       python3-pynest2d
Requires:       python3-pyserial
Requires:       python3-qt5 >= 5.10
Requires:       python3-requests
Requires:       python3-scipy
Requires:       python3-sentry-sdk
Requires:       python3-shapely
Requires:       python3-typing
Requires:       uranium >= %{version}
Recommends:     cura-fdm-materials >= %{version}
Recommends:     python3-trimesh
Recommends:     python3-zeroconf
BuildArch:      noarch
# The CuraEngine is not supported on 32bit Linux anymore
ExcludeArch:    %ix86 %arm s390 ppc

%description
Cura is a project which aims to be an single software solution for 3D printing.
While it is developed to be used with the Ultimaker 3D printer, it can be used
with other RepRap based designs.

Cura helps setting up an Ultimaker, shows the 3D model, allows for scaling /
positioning, can slice the model to G-Code with editable configuration
settings, and send this G-Code to the 3D printer for printing.

%prep
%autosetup -n Cura-%sversion -p1
sed -i -e '1 s/env python3/python3/' cura_app.py

%build
export CFLAGS="%{optflags}"
# Hack, remove LIB_SUFFIX for 64bit, which is correct as cura is pure python (i.e. noarch)
%cmake -DLIB_SUFFIX="" \
       -DCURA_BUILDTYPE=RPM \
       -DCURA_CLOUD_API_ROOT:STRING=https://api.ultimaker.com \
       -DCURA_CLOUD_API_VERSION:STRING=1 \
       -DCURA_CLOUD_ACCOUNT_API_ROOT:STRING=https://account.ultimaker.com \
       -DCURA_VERSION=%version \
       -DCURA_DEBUGMODE=OFF \
       %{nil}
%cmake_build

%install
%cmake_install

for x in 128 64 48 32; do
    install -m 755 -d %{buildroot}%{_datadir}/icons/hicolor/${x}x${x}/apps/
    install -m 644 icons/cura-${x}.png %{buildroot}%{_datadir}/icons/hicolor/${x}x${x}/apps/cura-icon.png
done

# i18n sources (po/pot) are installed in cura/resources, .mo in uranium/resources
rm -Rf %{buildroot}%{_datadir}/%{name}/resources/i18n
# uranium uses i18n instead of locale for the path to translation files,
# thus we cannot use %%find_lang
echo '%defattr(644,root,root,755)' > %{name}.lang
find %{buildroot}%{_datadir}/cura -name *.mo | sed '
  s:'%{buildroot}'::; s:\(.*/i18n/\)\([^/]\+\)\(.*mo\):%lang(\2) \1\2\3:' \
  >> %{name}.lang

%fdupes -s %{buildroot}%{_datadir}/%{name}
%suse_update_desktop_file com.ultimaker.cura Graphics 3DGraphics

%check
cd build
make CTEST_OUTPUT_ON_FAILURE=TRUE test

%files -f %{name}.lang
%license LICENSE
%doc README.md
%{python3_sitelib}/cura
%{_datadir}/%{name}
%{_datadir}/applications/com.ultimaker.cura.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/com.ultimaker.cura.appdata.xml
%{_datadir}/mime/packages/cura.xml
%{_datadir}/icons/hicolor
%{_bindir}/cura
%{_prefix}/lib/cura

%changelog
* Tue Jun 21 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix broken sentry_sdk import, add remove_unused_sentry_sdk.patch
  (boo#1199506)
* Sun Feb  6 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.13.1
  Release notes:
  https://github.com/Ultimaker/Cura/releases/tag/4.13.1
* Thu Jan 27 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 4.13.0
  Release notes:
  https://github.com/Ultimaker/Cura/releases/tag/4.13.0
* Mon Apr 26 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.9.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.9
- Drop 0001-Avoid-crash-caused-by-KDE-qqc2-desktop-style.patch
- Remove manually added package dependencies for QML
* Sat Jan 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Mon Dec  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Resurrect 0001-Avoid-crash-caused-by-KDE-qqc2-desktop-style.patch
- Correct icon install paths
* Sat Nov 21 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Depend on the python3-Arcus bindings instead of the versioned
  library.
* Tue Nov 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.8.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.8
- Rebase disable-code-style-check.patch
* Tue Sep 15 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.7.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.7.1
  * https://github.com/Ultimaker/Cura/releases/tag/4.7.0
  * https://github.com/Ultimaker/Cura/releases/tag/4.6.2
- Drop obsolete
  0001-Avoid-crash-caused-by-KDE-qqc2-desktop-style.patch
* Sun Jun  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.6.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.6.1
  * https://github.com/Ultimaker/Cura/releases/tag/4.6.0
  * https://github.com/Ultimaker/Cura/releases/tag/4.5.0
- Drop unneeded patches:
  * fix-crash-on-start.patch
  * fix-runtime.patch
- Rebase 0001-Avoid-crash-caused-by-KDE-qqc2-desktop-style.patch
* Tue Mar 31 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove pkgconfig(Qt5Core) from runtime dependencies, pulls in
  a huge set of Qt5 devel packages.
* Thu Feb 20 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Avoid crash when qqc2-desktop-style is installed and used as
  default style (typically by a KDE Plasma session):
  * 0001-Avoid-crash-caused-by-KDE-qqc2-desktop-style.patch
* Thu Jan  2 2020 Adrian Schröter <adrian@suse.de>
- update to version 4.4.1
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/v4.4.1
* Fri Nov 22 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.4.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/v4.4.0
* Fri Sep 27 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.3.0
  Release notes:
  * https://github.com/Ultimaker/Cura/releases/tag/4.3.0
* Mon Aug 12 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.2.1
  * https://ultimaker.com/en/blog/52912-ultimaker-cura-42-first-choice-for-3d-printing-professionals-worldwide
* Thu Jun 13 2019 Adrian Schröter <adrian@suse.de>
- update to version 4.1.0
  * https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
  * Requires Qt 5.10 or later. So no builds for openSUSE Leap atm.
  * added disable-code-style-check.patch  fix-crash-on-start.patch  fix-runtime.patch
- enable tests
  * but skip code stylce checks disable-code-style-check.patch
* Sat Mar  9 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Spec cleanup:
  * Update URL to use https
  * Remove %%defattr
* Fri Nov 16 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.6.0
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Wed Oct 17 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.5.1
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Wed Aug  8 2018 jengelh@inai.de
- Do not assume a particular user.
* Mon Aug  6 2018 adrian@suse.de
- add recommends to python3-Savitar for 3mf plugin
* Mon Jul 16 2018 adrian@suse.de
- update to version 3.4.1
  https://ultimaker.com/en/products/ultimaker-cura-software/release-notes
* Mon Jul  9 2018 adrian@suse.de
- update to version 3.3.1
  * Ultimaker S5 support
* Fri Mar 30 2018 bugs@vdm-design.de
- Add runtime dependency to python3-typing
  Cura doens't start without it
* Sat Jan 27 2018 stefan.bruens@rwth-aachen.de
- Fix incorrect install path, make package noarch again
* Sun Jan 14 2018 stefan.bruens@rwth-aachen.de
- Add missing runtime requirement to python3-scipy
* Fri Dec  8 2017 stefan.bruens@rwth-aachen.de
- Fix License, Cura 3.0 and libraries are LGPL-3.0 now
* Thu Dec  7 2017 stefan.bruens@rwth-aachen.de
- Update to version 3.0.3
- Drop no longer needed
  0001-adapt-python-install-dir-to-SUSE-convention.patch
- Use proper RPM Group, Hardware/Printing (Applications/Engineering
  no longer exists)
* Thu Sep 28 2017 stefan.bruens@rwth-aachen.de
- Set required python version to 3.4.0 in *all* cmake files, allow
  builds on Leap 42.3
* Wed Sep 13 2017 stefan.bruens@rwth-aachen.de
- Update to version 2.7.0
* Fri Mar 17 2017 stefan.bruens@rwth-aachen.de
- Removed unused python runtime dependencies
- Recommend (not yet available) python3-zeroconf for UM3
  network discovery/printing
* Thu Mar 16 2017 stefan.bruens@rwth-aachen.de
- Package cura.appdata.xml
- Update RPM URL/Source to official Ultimaker github repositories
- redo and rename fix_build.patch, replace with
  0001-adapt-python-install-dir-to-SUSE-convention.patch
* Wed Mar 15 2017 bugs@vdm-design.de
- Update to version 2.4.0
* Wed Nov 23 2016 stefan.bruens@rwth-aachen.de
- Cleanup specfile:
  * delete .po/.pot files
  * proper packaging of translations (%%lang tag)
  * install icons to hicolor dir
  * removed unnecessary buildrequires
  * delete google-opensans-fonts copy
* Sun Nov  6 2016 bugs@vdm-design.de
- Update to version 2.3.1
* Mon Jun 20 2016 adrian@suse.de
- switch to git master
* Sun Nov 15 2015 boris@steki.net
- updated to latest upstream version 15.04
* Tue Oct  7 2014 boris@steki.net
- Updated to latest upstream version 14.09
* Sun May  4 2014 boris@steki.net
- Development
  * Added an expert parameter for the wipe tower size, and made brim go around the wipe tower
  * Added experimental support for printing with the Doodle3D WiFi box
  * Updated object boundaries for multi-object prints, allows for tighter fitting of objects on the build platform
  * Updated time-estimate to greatly improve accuracy of the estimate.
  * Fixed problem with retractions not happening when they should.
  * Added keyboard control for the 3D window to look around with cursor keys.
- Ultimaker2 - Firmware update - 13.12
  * Fixed the problem where aborting a print did not always home the head.
  * Fixed bug in acceleration planning causing slow moves on rare occasions.
  * Disable the normal menus during USB printing, and support for USB based menus.
  * Disable stepper drivers after print is finished or aborted, so you can manually move the head.
  * Expert feature: Support M907 for setting the motor current.
- Ultimaker Original - Firmware update - 13.12
  * Fixed bug in acceleration planning causing slow moves on rare occasions.
  * Updated to new ErikZalm Marlin base, fixing the long standing slower retraction bug.
* Sat Oct 12 2013 lzwang@suse.com
- Initial package of Cura
